==> moodle-1.5-mysql.tgz: moodle/lang/th/resource.php <==
<?PHP // $Id$ 
      // resource.php - created with Moodle 1.6 development (2005052400)


$string['addresource'] = '觢';
$string['chooseafile'] = '͡ѾŴ';
$string['chooseparameter'] = '͡';
$string['configdefaulturl'] = 'ҹС͡ URL ѵѵ͵ͧҧ觢 URL ';
$string['configfilterexternalpages'] = '͡õ駤Ẻ觼觢¹͡ (ྨ htmlҧ١ѾŴ) ١Ѵ¤ҷ䫵˹  ͤس͡õ駤ẺҨзԴԪ¹ŧҧҡ  й鹡س¤Ѵѧ  ͨҹ';
$string['configframesize'] = 'ʴྨѾŴ㹡ͺ Ҵͧҹ (ԡ) ͤҢͧҴͺ ';
$string['configparametersettings'] = 'ٻẺõ駤ҵ㹡觢 ҹ繤ҷкѺҪԡФ';
$string['configpopup'] = '㹡觢  سͧѹҡ˹ҵҧ';
$string['configpopupdirectories'] = '˹ҵҧҡ鹤èʴ¡ԧ';
$string['configpopupheight'] = '˹٧ͧ˹ҵҧлҡ';
$string['configpopuplocation'] = '˹ҵҧҡ鹤èʴᶺ';
$string['configpopupmenubar'] = '˹ҵҧҡ鹤è¡õ͡';
$string['configpopupresizable'] = '˹ҵҧҡ鹤èö͢';
$string['configpopupscrollbars'] = '˹ҵҧҡ鹤èᶺ͹ŧ';
$string['configpopupstatus'] = '˹ҵҧҡ鹤èᶺʶҹд';
$string['configpopuptoolbar'] = '˹ҵҧҡ鹤èᶺŴ';
$string['configpopupwidth'] = '˹ҧͧ˹ҵҧлҡ';
$string['configsecretphrase'] = '¤Ѻ㹡ա觢ٻẺͧ  鴴ѧǹաٻẺ md5  ;շس »¤Ѻ    code = md5(IP.secretphrase) ͤʹ·ҡ';
$string['configwebsearch'] = '㹡÷ URL ԧྨ  شçЪҪԡö URL ͧ¢';
$string['configwindowsettings'] = '駤˹ҵҧ㹡觢 ҹ繤ҷкѺҪԡФ';
$string['directlink'] = 'ԧѧ';
$string['directoryinfo'] = 'ʴ͡áչ';
$string['display'] = '˹ҵҧ';
$string['editingaresource'] = '觢';
$string['encryptedcode'] = 'ʷҹýѧ';
$string['example'] = 'ҧ';
$string['exampleurl'] = 'http://www.example.com/somedirectory/somefile.html';
$string['fetchclienterror'] = 'ͼԴҴ㹡¡ྨسͧ (ҨԴҡ URL ١ͧ)';
$string['fetcherror'] = 'ͼԴҴ㹡¡ྨ';
$string['fetchservererror'] = 'ͼԴҴҧ¡ྨ (ҨԴҡԴҴͧ)';
$string['filename'] = '';
$string['filtername'] = 'ԧѧ觢ѵѵ';
$string['frameifpossible'] = '觢ͧ site navigation';
$string['fulltext'] = '';
$string['htmlfragment'] = 'HTML fragment';
$string['maindirectory'] = 'áѡ';
$string['modulename'] = '觢';
$string['modulenameplural'] = '觢';
$string['neverseen'] = '';
$string['newdirectories'] = 'ʴԧѧä';
$string['newfullscreen'] = 'ʴ˹Ҩ';
$string['newheight'] = '٧ͧԹ컡 (ԡ)';
$string['newlocation'] = 'ʴᶺ url';
$string['newmenubar'] = 'ʴᶺ';
$string['newresizable'] = '͹حҵ¹ҴͧԹ';
$string['newscrollbars'] = '͹حҵաʡԹ';
$string['newstatus'] = 'ʴᶺʶҹ';
$string['newtoolbar'] = 'ʴᶺͧ';
$string['newwidth'] = 'ҧͧԹ (ԡ)';
$string['newwindow'] = '˹ҵҧ';
$string['newwindowopen'] = 'ʴ觢˹ҵҧ';
$string['note'] = '˵';
$string['notefile'] = 'ҡͧѾŴ ѺԪҹس
<a href=\"$a\">File Manager</a>.';
$string['notypechosen'] = 'سͧ͡ س  back ͡Ѻ͡';
$string['pagedisplay'] = 'ʴ觢˹ҵҧѨغѹ';
$string['pagewindow'] = '˹ҵҧ';
$string['parameter'] = '';
$string['parameters'] = '';
$string['popupresource'] = '觢Źèлҡ˹ҵҧѴ';
$string['popupresourcelink'] = 'ҡ  ԡ: $a';
$string['resourcetype'] = 'ͧ觢';
$string['resourcetype1'] = 'ҧԧ';
$string['resourcetype2'] = 'ྨ';
$string['resourcetype3'] = 'ѾŴ';
$string['resourcetype4'] = '˹ѧ͸';
$string['resourcetype5'] = 'ԧ';
$string['resourcetype6'] = 'HTML';
$string['resourcetype7'] = '';
$string['resourcetype8'] = 'Wiki';
$string['resourcetype9'] = 'á';
$string['resourcetypedirectory'] = 'á';
$string['resourcetypefile'] = '䫵';
$string['resourcetypehtml'] = '˹ྨ';
$string['resourcetypelabel'] = 'Label';
$string['resourcetypetext'] = '˹ҵ˹ѧ͸';
$string['searchweb'] = 'ྨ';
$string['variablename'] = '͵';

?>

==> moodle-1.5.3-mysql.tgz: moodle/lang/th/resource.php <==
<?PHP // $Id$ 
      // resource.php - created with Moodle 1.4.2 (2004083125)


$string['addresource'] = '觢';
$string['chooseafile'] = '͡ѾŴ';
$string['chooseparameter'] = '͡';
$string['configdefaulturl'] = 'ҹС͡ URL ѵѵ͵ͧҧ觢 URL ';
$string['configfilterexternalpages'] = '͡õ駤Ẻ觼觢¹͡ (ྨ htmlҧ١ѾŴ) ١Ѵ¤ҷ䫵˹  ͤس͡õ駤ẺҨзԴԪ¹ŧҧҡ  й鹡س¤Ѵѧ  ͨҹ';
$string['configframesize'] = 'ʴྨѾŴ㹡ͺ Ҵͧҹ (ԡ) ͤҢͧҴͺ ';
$string['configparametersettings'] = 'ٻẺõ駤ҵ㹡觢 ҹ繤ҷкѺҪԡФ';
$string['configpopup'] = '㹡觢  سͧѹҡ˹ҵҧ';
$string['configpopupdirectories'] = '˹ҵҧҡ鹤èʴ¡ԧ';
$string['configpopupheight'] = '˹٧ͧ˹ҵҧлҡ';
$string['configpopuplocation'] = '˹ҵҧҡ鹤èʴᶺ';
$string['configpopupmenubar'] = '˹ҵҧҡ鹤è¡õ͡';
$string['configpopupresizable'] = '˹ҵҧҡ鹤èö͢';
$string['configpopupscrollbars'] = '˹ҵҧҡ鹤èᶺ͹ŧ';
$string['configpopupstatus'] = '˹ҵҧҡ鹤èᶺʶҹд';
$string['configpopuptoolbar'] = '˹ҵҧҡ鹤èᶺŴ';
$string['configpopupwidth'] = '˹ҧͧ˹ҵҧлҡ';
$string['configsecretphrase'] = '¤Ѻ㹡ա觢ٻẺͧ  鴴ѧǹաٻẺ md5  ;շس »¤Ѻ    code = md5(IP.secretphrase) ͤʹ·ҡ';
$string['configwebsearch'] = '㹡÷ URL ԧྨ  شçЪҪԡö URL ͧ¢';
$string['configwindowsettings'] = '駤˹ҵҧ㹡觢 ҹ繤ҷкѺҪԡФ';
$string['directlink'] = 'ԧѧ';
$string['directoryinfo'] = 'ʴ͡áչ';
$string['display'] = '˹ҵҧ';
$string['editingaresource'] = '觢';
$string['encryptedcode'] = 'ʷҹýѧ';
$string['example'] = 'ҧ';
$string['exampleurl'] = 'http://www.example.com/somedirectory/somefile.html';
$string['fetchclienterror'] = 'ͼԴҴ㹡¡ྨسͧ (ҨԴҡ URL ١ͧ)';
$string['fetcherror'] = 'ͼԴҴ㹡¡ྨ';
$string['fetchservererror'] = 'ͼԴҴҧ¡ྨ (ҨԴҡԴҴͧ)</p>';
$string['filename'] = '';
$string['filtername'] = 'ԧѧ觢ѵѵ';
$string['frameifpossible'] = '觢ͧ site navigation';
$string['fulltext'] = '';
$string['htmlfragment'] = 'HTML fragment';
$string['maindirectory'] = 'áѡ';
$string['modulename'] = '觢';
$string['modulenameplural'] = '觢';
$string['neverseen'] = '';
$string['newdirectories'] = 'ʴԧѧä';
$string['newfullscreen'] = 'ʴ˹Ҩ';
$string['newheight'] = '٧ͧԹ컡 (ԡ)';
$string['newlocation'] = 'ʴᶺ url';
$string['newmenubar'] = 'ʴᶺ';
$string['newresizable'] = '͹حҵ¹ҴͧԹ';
$string['newscrollbars'] = '͹حҵաʡԹ';
$string['newstatus'] = 'ʴᶺʶҹ';
$string['newtoolbar'] = 'ʴᶺͧ';
$string['newwidth'] = 'ҧͧԹ (ԡ)';
$string['newwindow'] = '˹ҵҧ';
$string['newwindowopen'] = 'ʴ觢˹ҵҧ';
$string['note'] = '˵';
$string['notefile'] = 'ҡͧѾŴ ѺԪҹس
<A HREF=$a >File Manager</A>.';
$string['notypechosen'] = 'سͧ͡ س  back ͡Ѻ͡';
$string['pagedisplay'] = 'ʴ觢˹ҵҧѨغѹ';
$string['pagewindow'] = '˹ҵҧ';
$string['parameter'] = '';
$string['parameters'] = '';
$string['parentlanguage'] = 'en';
$string['popupresource'] = '觢Źèлҡ˹ҵҧѴ';
$string['popupresourcelink'] = 'ҡ  ԡ: $a';
$string['resourcetype'] = 'ͧ觢';
$string['resourcetype1'] = 'ҧԧ';
$string['resourcetype2'] = 'ྨ';
$string['resourcetype3'] = 'ѾŴ';
$string['resourcetype4'] = '˹ѧ͸';
$string['resourcetype5'] = 'ԧ';
$string['resourcetype6'] = 'HTML';
$string['resourcetype7'] = '';
$string['resourcetype8'] = 'Wiki';
$string['resourcetype9'] = 'á';
$string['resourcetypedirectory'] = 'á';
$string['resourcetypefile'] = '䫵';
$string['resourcetypehtml'] = '˹ྨ';
$string['resourcetypelabel'] = 'Label';
$string['resourcetypetext'] = '˹ҵ˹ѧ͸';
$string['searchweb'] = 'ྨ';
$string['thischarset'] = 'TIS-620';
$string['thisdirection'] = 'ltr';
$string['thislanguage'] = 'Thai';
$string['variablename'] = '͵';

?>
